@@ -1,25 +1,29 @@
 package Acme::Backwards; 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 use Keyword::Declare;
+use Data::Dumper;
 sub import {
 	keytype OKAY is m{(?:fisle (?&PerlNWS)(?&PerlExpression).*?;|esle (?&PerlNWS).*?;)?+}xms;
 	keyword fi (Expr $test, /.+?;/ $code, OKAY @next) {_backwards('if', $test, $code)._process_backwards(@next);};
 	keyword sselnu (Expr $test, /.+?;/ $code, OKAY @next) {_backwards('unless', $test, $code)._process_backwards(@next);};
+	keyword rof (/(my\s*\$\w+)?/ $declare, Expr $test, /.+?;/ $code) {_backwards('for', ($declare ? $declare : ()), $test, $code);};
+
 }
 sub _process_backwards {join' ',map{$_=~m/(fisle|esle)(.*)$/;return"_$1"->($2)}@_;}
 sub _esle {_backwards('else','',shift)}
 sub _fisle {shift=~m/\s*((?&PerlExpression))\s*(.*?;) $PPR::GRAMMAR/gxm;_backwards('elsif', $1, $2);}
-sub _backwards {sprintf"%s %s { %s }",@_;}
+sub _backwards {scalar@_>3?sprintf"%s %s %s { %s }",@_:sprintf"%s %s { %s }",@_;}
+
 1;
 __END__
 
 =head1 NAME
 
-Acme::Backwards - One line fi, esle, fisle, sselnu
+Acme::Backwards - One line fi, esle, fisle, sselnu, rof
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
@@ -40,6 +44,11 @@ Perhaps a little code snippet.
 	fisle ( $str eq 'backwards' ) say $str;
 	esle die $str;
 
+	my $int = 0;
+	rof (qw/1 2 3/) $int += $_;
+	rof my $var (qw/4 5 6/) $int += $var;
+
+
 =head1 AUTHOR
 
 LNATION, C<< <thisusedtobeanemail at gmail.com> >>
